SystemOrganization addCategory: #'MCFeed-Core'!

Object subclass: #MCFeed
	instanceVariableNames: 'directory feedFile feedUrl name repositoryUrl size'
	classVariableNames: 'Feeds'
	poolDictionaries: ''
	category: 'MCFeed-Core'!

!MCFeed class methodsFor: 'building' stamp: 'cwp 7/27/2007 19:01'!
build: feedname
	| feed |
	feed := Feeds detect: [:ea | ea name = feedname] ifNone: [^ self].
	feed build! !

!MCFeed class methodsFor: 'building' stamp: 'cwp 7/27/2007 19:02'!
buildAll
	Feeds do: [:ea | ea build]! !

!MCFeed class methodsFor: 'accessing' stamp: 'cwp 7/29/2007 01:30'!
feeds
	^ Feeds! !

!MCFeed class methodsFor: 'class initialization' stamp: 'cwp 7/27/2007 18:55'!
initialize
	Feeds := Set new.
	Smalltalk addToStartUpList: self! !

!MCFeed class methodsFor: 'building' stamp: 'cwp 7/27/2007 19:19'!
startUp: resuming
	resuming ifFalse: [^ self].
	SmalltalkImage current extractParameters at: 'BUILD' ifPresent: 
		[:feedname |
		feedname = 'ALL'
			ifTrue: [self buildAll]
			ifFalse: [self build: feedname].
		SmalltalkImage current snapshot: false andQuit: true]! !

!MCFeed methodsFor: 'comparing' stamp: 'cwp 7/27/2007 18:29'!
= other
	^ self feedFile = other feedFile! !

!MCFeed methodsFor: 'building' stamp: 'cwp 7/27/2007 18:24'!
build
	MCFeedBuilder new
		name: name;
		baseUrl: repositoryUrl;
		directory: directory;
		build: size;
		writeFeedTo: feedFile! !

!MCFeed methodsFor: 'accessing' stamp: 'cwp 7/27/2007 18:18'!
directory
	^ directory! !

!MCFeed methodsFor: 'accessing' stamp: 'cwp 7/27/2007 18:19'!
directory: anObject
	directory := anObject! !

!MCFeed methodsFor: 'accessing' stamp: 'cwp 7/27/2007 18:19'!
feedFile
	^ feedFile! !

!MCFeed methodsFor: 'accessing' stamp: 'cwp 7/27/2007 18:19'!
feedFile: anObject
	feedFile := anObject! !

!MCFeed methodsFor: 'accessing' stamp: 'cwp 7/27/2007 18:19'!
feedUrl
	^ feedUrl! !

!MCFeed methodsFor: 'accessing' stamp: 'cwp 7/27/2007 18:19'!
feedUrl: anObject
	feedUrl := anObject! !

!MCFeed methodsFor: 'comparing' stamp: 'cwp 7/27/2007 18:29'!
hash
	^ feedFile hash! !

!MCFeed methodsFor: 'accessing' stamp: 'cwp 7/27/2007 18:20'!
name
	^ name! !

!MCFeed methodsFor: 'accessing' stamp: 'cwp 7/27/2007 18:19'!
name: anObject
	name := anObject! !

!MCFeed methodsFor: 'accessing' stamp: 'cwp 7/27/2007 18:19'!
repositoryUrl
	^ repositoryUrl! !

!MCFeed methodsFor: 'accessing' stamp: 'cwp 7/27/2007 18:19'!
repositoryUrl: anObject
	repositoryUrl := anObject! !

!MCFeed methodsFor: 'building' stamp: 'cwp 7/29/2007 00:52'!
save
	Feeds 
		remove: self ifAbsent: [];
		add: self! !

!MCFeed methodsFor: 'accessing' stamp: 'cwp 7/27/2007 18:19'!
size
	^ size! !

!MCFeed methodsFor: 'accessing' stamp: 'cwp 7/27/2007 18:19'!
size: anObject
	size := anObject! !

Object subclass: #MCFeedBuilder
	instanceVariableNames: 'name baseUrl repository feed'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MCFeed-Core'!

!MCFeedBuilder methodsFor: 'accessing' stamp: 'cwp 7/30/2007 00:43'!
baseUrl: aString
	baseUrl := aString! !

!MCFeedBuilder methodsFor: 'building' stamp: 'cwp 7/27/2007 00:48'!
build: size
	feed := AtomFeed new.
	self decorateFeed.
	(self last: size versionsFrom: repository)
		 do: [:ea | feed addEntry: (self entryForVersion: ea)].
	! !

!MCFeedBuilder methodsFor: 'building' stamp: 'cwp 7/27/2007 01:52'!
contentForVersion: aVersion
	^ AtomTextHTML new
		text: (MCEntryContent version: aVersion repository: repository) text;
		yourself! !

!MCFeedBuilder methodsFor: 'building' stamp: 'cwp 9/26/2007 20:43'!
decorateFeed
	feed
		id: baseUrl;
		titleText: name;
		updated: DateAndTime now;
		addLink: self linkForFeed! !

!MCFeedBuilder methodsFor: 'accessing' stamp: 'cwp 7/27/2007 00:39'!
directory: aString
	repository := MCDirectoryRepository new.
	repository directory: (FileDirectory on: aString)! !

!MCFeedBuilder methodsFor: 'building' stamp: 'cwp 7/27/2007 01:49'!
entryForVersion: aVersion
	| entry info |
	info := aVersion info.
	entry := AtomEntry new.
	entry id: 'uuid:', info id asString.
	entry titleText: info name.
	entry updated: (DateAndTime date: info date time: info time)..
	entry addAuthor: (AtomPerson new name: info author).
	entry addLink: (self linkForVersion: aVersion).
	entry summaryText: info message.
	entry content: (self contentForVersion: aVersion).
	^ entry! !

!MCFeedBuilder methodsFor: 'writing' stamp: 'cwp 7/27/2007 00:33'!
feedString
	^ String streamContents: [:stream | self writeFeedOn: stream]! !

!MCFeedBuilder methodsFor: 'building' stamp: 'cwp 7/31/2007 01:02'!
last: anInteger versionsFrom: aRepository
	^ (aRepository allFileNames first: anInteger) 
		collect: [:ea | aRepository loadVersionFromFileNamed: ea]! !

!MCFeedBuilder methodsFor: 'building' stamp: 'cwp 7/30/2007 00:43'!
linkForFeed
	^ AtomLink new
		beAlternate;
		href: baseUrl;
		title: name, ' Repository';
		yourself! !

!MCFeedBuilder methodsFor: 'building' stamp: 'cwp 7/30/2007 00:43'!
linkForVersion: aVersion
	^ AtomLink new
		beEnclosure;
		href: baseUrl, aVersion fileName
		yourself
		! !

!MCFeedBuilder methodsFor: 'accessing' stamp: 'cwp 7/27/2007 00:44'!
name: aString
	name := aString! !

!MCFeedBuilder methodsFor: 'writing' stamp: 'cwp 7/29/2007 00:14'!
writeFeedOn: aStream 
	^ feed xmlDocumentOn: aStream! !

!MCFeedBuilder methodsFor: 'writing' stamp: 'cwp 7/27/2007 00:35'!
writeFeedTo: aString
	| f |
	f := FileStream forceNewFileNamed: aString.
	[self writeFeedOn: f]
		ensure: [f ifNotNil: [f close]]! !

MCVersionNotification subclass: #MCEntryContent
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MCFeed-Core'!

!MCEntryContent methodsFor: 'as yet unclassified' stamp: 'cwp 7/27/2007 01:56'!
printDiff: aModification on: aStream
	| builder |
	builder := TextDiffBuilder 
		from: aModification fromSource 
		to: aModification toSource.
	builder buildPatchSequence do:
		[:assoc |
		assoc key = #insert 
			ifTrue: [aStream nextPutAll: '+ '] 
			ifFalse:
				[assoc key = #remove 
					ifTrue: [aStream nextPutAll: '- '] 
					ifFalse: [aStream nextPutAll: '  ']].
		aStream feedContent: assoc value; br]! !

!MCEntryContent methodsFor: 'as yet unclassified' stamp: 'cwp 7/27/2007 01:59'!
text
	^ String streamContents:
		[:s |
		s feedContent: version summary.
		changes isEmpty ifFalse:
			[s 
				br; br;
				nextPutAll: '-----------------------------------------------------'; br;
				nextPutAll: 'Changes since ';
				feedContent: ancestor info name;
				nextPut: $:; br.
			changes do:
				[:ea |
				s br; feedContent: ea summary; br.
				self printDiff: ea on: s]]]! !
MCFeed initialize!
